import { BinaryPropertyTable } from "./BinaryPropertyTable";
import { MetadataEntityModel } from "../MetadataEntityModel";
import { PropertyModel } from "../PropertyModel";
import { PropertyTableModel } from "../PropertyTableModel";
import { ClassProperty } from "../../structure/Metadata/ClassProperty";
import { PropertyTableProperty } from "../../structure/PropertyTableProperty";
/**
 * Implementation of the `PropertyTableModel` interface that is backed
 * by binary data.
 *
 * @internal
 */
export declare class BinaryPropertyTableModel implements PropertyTableModel {
    /**
     * The structure containing the raw data of the binary
     * property table
     */
    private readonly _binaryPropertyTable;
    /**
     * A mapping from property IDs to the `PropertyModel`
     * instances that provide the property values. These
     * are the "columns" of the table
     */
    private readonly _propertyIdToModel;
    /**
     * A mapping from 'semantic' strings to the 'propertyId'
     * strings of the properties that have the respective
     * semantic
     */
    private readonly _semanticToPropertyId;
    constructor(binaryPropertyTable: BinaryPropertyTable);
    /** {@inheritDoc PropertyTableModel.getMetadataEntityModel} */
    getMetadataEntityModel(index: number): MetadataEntityModel;
    /** {@inheritDoc PropertyTableModel.getPropertyModel} */
    getPropertyModel(propertyId: string): PropertyModel | undefined;
    /** {@inheritDoc PropertyTableModel.getClassProperty} */
    getClassProperty(propertyId: string): ClassProperty | undefined;
    /** {@inheritDoc PropertyTableModel.getPropertyTableProperty} */
    getPropertyTableProperty(propertyId: string): PropertyTableProperty | undefined;
}
//# sourceMappingURL=BinaryPropertyTableModel.d.ts.map