"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BooleanArrayPropertyModel = void 0;
const BinaryPropertyModels_1 = require("./BinaryPropertyModels");
const BooleanPropertyModel_1 = require("./BooleanPropertyModel");
/**
 * Implementation of a `PropertyModel` for boolean arrays
 *
 * @internal
 */
class BooleanArrayPropertyModel {
    constructor(valuesBuffer, arrayOffsetsBuffer, arrayOffsetType, count) {
        this._valuesBuffer = valuesBuffer;
        this._arrayOffsetsBuffer = arrayOffsetsBuffer;
        this._arrayOffsetType = arrayOffsetType;
        this._count = count;
    }
    /** {@inheritDoc PropertyModel.getPropertyValue} */
    getPropertyValue(index) {
        const valuesBuffer = this._valuesBuffer;
        const arrayOffsetsBuffer = this._arrayOffsetsBuffer;
        const arrayOffsetType = this._arrayOffsetType;
        const count = this._count;
        const arraySlice = BinaryPropertyModels_1.BinaryPropertyModels.computeSlice(index, arrayOffsetsBuffer, arrayOffsetType, count);
        const arrayOffset = arraySlice.offset;
        const arrayLength = arraySlice.length;
        const result = new Array(arrayLength);
        for (let i = 0; i < arrayLength; i++) {
            const n = arrayOffset + i;
            const element = BooleanPropertyModel_1.BooleanPropertyModel.getBooleanFromBuffer(valuesBuffer, n);
            result[i] = element;
        }
        return result;
    }
}
exports.BooleanArrayPropertyModel = BooleanArrayPropertyModel;
