"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StringArrayPropertyModel = void 0;
const BinaryPropertyModels_1 = require("./BinaryPropertyModels");
const ArrayBuffers_1 = require("./ArrayBuffers");
/**
 * Implementation of a `PropertyModel` for string arrays
 *
 * @internal
 */
class StringArrayPropertyModel {
    constructor(valuesBuffer, arrayOffsetsBuffer, arrayOffsetType, stringOffsetsBuffer, stringOffsetType, count) {
        this._valuesBuffer = valuesBuffer;
        this._arrayOffsetsBuffer = arrayOffsetsBuffer;
        this._arrayOffsetType = arrayOffsetType;
        this._stringOffsetsBuffer = stringOffsetsBuffer;
        this._stringOffsetType = stringOffsetType;
        this._count = count;
    }
    /** {@inheritDoc PropertyModel.getPropertyValue} */
    getPropertyValue(index) {
        const valuesBuffer = this._valuesBuffer;
        const arrayOffsetsBuffer = this._arrayOffsetsBuffer;
        const arrayOffsetType = this._arrayOffsetType;
        const stringOffsetsBuffer = this._stringOffsetsBuffer;
        const stringOffsetType = this._stringOffsetType;
        const count = this._count;
        const arraySlice = BinaryPropertyModels_1.BinaryPropertyModels.computeSlice(index, arrayOffsetsBuffer, arrayOffsetType, count);
        const arrayOffset = arraySlice.offset;
        const arrayLength = arraySlice.length;
        const result = new Array(arrayLength);
        for (let i = 0; i < arrayLength; i++) {
            const n = arrayOffset + i;
            const stringSlice = BinaryPropertyModels_1.BinaryPropertyModels.computeSlice(n, stringOffsetsBuffer, stringOffsetType, undefined);
            const stringOffset = stringSlice.offset;
            const stringLength = stringSlice.length;
            const arrayBuffer = ArrayBuffers_1.ArrayBuffers.fromBuffer(valuesBuffer);
            const element = StringArrayPropertyModel.decoder.decode(arrayBuffer.slice(stringOffset, stringOffset + stringLength));
            result[i] = element;
        }
        return result;
    }
}
exports.StringArrayPropertyModel = StringArrayPropertyModel;
// Implementation note:
// Either the `arrayOffsetsBuffer` or the `count` may be undefined.
// When `arrayOffsetsBuffer` is defined, then this indicates a
// variable-length array. When the `count` is defined, then this
// indicates a fixed-length array.
StringArrayPropertyModel.decoder = new TextDecoder();
