import { TilesetTarget } from "./TilesetTarget";
import { TilesetEntry } from "./TilesetEntry";
/**
 * Methods related to `TilesetTarget` instances
 *
 * @internal
 */
export declare class TilesetTargets {
    /**
     * Create a tileset target for the given name, and prepare
     * it to accept entries.
     *
     * The given name may have the extension `.3tz` or `.3dtiles`,
     * or no extension to indicate a directory.
     *
     * If the given name as the extension `.json`, then a target
     * for the directory that contains the given file is created.
     *
     * @param name - The name
     * @param overwrite - Whether existing output files should be overwritten
     * @returns The `TilesetTarget`
     * @throws TilesetError If the output can not be opened
     */
    static createAndBegin(name: string, overwrite: boolean): TilesetTarget;
    /**
     * Creates a TilesetTarget, based on the given
     * file extension
     *
     * @param extension - The extension: '.3tz' or '.3dtiles'
     * or the empty string (for a directory)
     * @returns The TilesetTarget, or `undefined` if the
     * extension is invalid
     */
    static create(extension: string): TilesetTarget | undefined;
    /**
     * Put all the given entries into the given tileset target.
     *
     * @param tilesetTarget - The `TilesetTarget`
     * @param entries - The iterator over the entries
     */
    static putEntries(tilesetTarget: TilesetTarget, entries: IterableIterator<TilesetEntry>): void;
}
//# sourceMappingURL=TilesetTargets.d.ts.map