import { Schema } from "../structure/Metadata/Schema";
import { BinarySubtreeData } from "../implicitTiling/BinarySubtreeData";
import { SubtreeInfo } from "../implicitTiling/SubtreeInfo";
import { SubtreeMetadataModel } from "./SubtreeMetadataModel";
/**
 * Methods to create `SubtreeMetadataModel` instances
 *
 * @internal
 */
export declare class SubtreeMetadataModels {
    /**
     * Creates a `SubtreeMetadataModel` from the given data.
     *
     * TODO Maybe add some proper comment here...
     *
     * @param binarySubtreeData - The `BinarySubtreeData`
     * @param subtreeInfo - The `SubtreeInfo`
     * @param schema - The metadata `Schema`
     * @returns The `SubtreeMetadataModel`
     */
    static create(binarySubtreeData: BinarySubtreeData, subtreeInfo: SubtreeInfo, schema: Schema): SubtreeMetadataModel;
    /**
     * Computes the mapping of indices inside the availability
     * information to the number that says how many elements
     * have been available up to this index, if the element
     * at the respective index is available.
     *
     * Yes, that sounds complicated. But it is used for accessing
     * the metadata that is stored in the subtree (see the 3D Tiles
     * specification, "ImplicitTiling - Tile Metadata").
     *
     * Quote:
     * "If `i` available tiles occur before a particular tile, that
     * tile’s property values are stored at index `i` of each
     * property value array."
     *
     * This means that when the availability bitstream is
     * [1, 0, 1, 1, 0] then this method will return an array
     * [0, _, 1, 2, _].
     *
     * The value of the `_` entries will be set to `-1`.
     *
     * @param availabilityInfo - The `AvailabilityInfo`
     * @returns The index mapping
     */
    private static computeAvailabilityIndexingMapping;
}
//# sourceMappingURL=SubtreeMetadataModels.d.ts.map